beamprofiler.iso.characterizing\_parameters.plateau\_uniformity
===============================================================

.. currentmodule:: beamprofiler.iso.characterizing_parameters

.. autofunction:: plateau_uniformity